"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var definitions_interface_1 = require("../definitions.interface");
var multi_field_1 = require("./multi-field");
describe('util/multi-field', function () {
    describe('MultiFieldUtils.multiFieldValueAsEntitiesIds', function () {
        it('test0', function () {
            var ids = multi_field_1.MultiFieldUtils.multiFieldValueAsEntitiesIds(definitions_interface_1.UNDEF);
            expect(ids).toEqual(definitions_interface_1.UNDEF);
        });
        it('test1', function () {
            var ids = multi_field_1.MultiFieldUtils.multiFieldValueAsEntitiesIds(null);
            expect(ids).toEqual(definitions_interface_1.UNDEF);
        });
        it('test2', function () {
            var ids = multi_field_1.MultiFieldUtils.multiFieldValueAsEntitiesIds([]);
            expect(ids).toEqual([]);
        });
        it('test3', function () {
            var ids = multi_field_1.MultiFieldUtils.multiFieldValueAsEntitiesIds([{ id: 1 }, { id: 2 }]);
            expect(ids).toEqual([1, 2]);
        });
        it('test4', function () {
            var ids = multi_field_1.MultiFieldUtils.multiFieldValueAsEntitiesIds({
                add: [],
                remove: [],
                edit: [],
                source: [],
            });
            expect(ids).toEqual([]);
        });
        it('test5', function () {
            var ids = multi_field_1.MultiFieldUtils.multiFieldValueAsEntitiesIds({
                add: [],
                remove: [],
                edit: [],
            });
            expect(ids).toEqual([]);
        });
        it('test6', function () {
            var ids = multi_field_1.MultiFieldUtils.multiFieldValueAsEntitiesIds({
                add: [{ id: 1 }],
                remove: [],
                edit: [],
                source: [],
            });
            expect(ids).toEqual([1]);
        });
        it('test7', function () {
            var ids = multi_field_1.MultiFieldUtils.multiFieldValueAsEntitiesIds({
                add: [{ id: 1 }, { id: 2 }],
                remove: [],
                edit: [],
                source: [],
            });
            expect(ids).toEqual([1, 2]);
        });
        it('test8', function () {
            var ids = multi_field_1.MultiFieldUtils.multiFieldValueAsEntitiesIds({
                add: [{ id: 1 }, { id: 2 }],
                remove: [],
                edit: [],
                source: [{ id: 3 }],
            });
            expect(ids).toEqual([1, 2, 3]);
        });
        it('test9', function () {
            var ids = multi_field_1.MultiFieldUtils.multiFieldValueAsEntitiesIds({
                add: [{ id: 1 }, { id: 2 }],
                remove: [{ id: 3 }],
                edit: [],
                source: [{ id: 3 }],
            });
            expect(ids).toEqual([1, 2]);
        });
        it('test10', function () {
            var ids = multi_field_1.MultiFieldUtils.multiFieldValueAsEntitiesIds({
                add: [],
                remove: [{ id: 3 }],
                edit: [],
                source: [{ id: 3 }],
            });
            expect(ids).toEqual([]);
        });
        it('test11', function () {
            var ids = multi_field_1.MultiFieldUtils.multiFieldValueAsEntitiesIds({
                add: [],
                remove: [{ id: 3 }],
                edit: [],
                source: [{ id: 3 }, { id: 4 }],
            });
            expect(ids).toEqual([4]);
        });
        it('test12', function () {
            var ids = multi_field_1.MultiFieldUtils.multiFieldValueAsEntitiesIds({
                add: [{ id: 1 }],
                remove: [],
                edit: [],
                source: [{ id: 2 }, { id: 3 }],
            });
            expect(ids).toEqual([1, 2, 3]);
        });
        it('test13', function () {
            var ids = multi_field_1.MultiFieldUtils.multiFieldValueAsEntitiesIds({
                add: [{ id: 1 }],
                remove: [],
                edit: [],
            });
            expect(ids).toEqual([1]);
        });
    });
});
//# sourceMappingURL=multi-field.spec.js.map